==> aws-cdk.aws-ivs-1.133.0.tar.gz: package/.warnings.jsii.js <==
function _aws_cdk_aws_ivs_LatencyMode(p) {
}
function _aws_cdk_aws_ivs_ChannelType(p) {
}
function _aws_cdk_aws_ivs_PlaybackKeyPairProps(p) {
}
function _aws_cdk_aws_ivs_IPlaybackKeyPair(p) {
}
function _aws_cdk_aws_ivs_IStreamKey(p) {
}
function _aws_cdk_aws_ivs_CfnStreamKeyProps(p) {
    if (p == null)
        return;
    visitedObjects.add(p);
    if (!visitedObjects.has(p.tags))
        require("@aws-cdk/core/.warnings.jsii.js")._aws_cdk_core_CfnTag(p.tags);
    visitedObjects.delete(p);
}
function _aws_cdk_aws_ivs_CfnPlaybackKeyPairProps(p) {
    if (p == null)
        return;
    visitedObjects.add(p);
    if (!visitedObjects.has(p.tags))
        require("@aws-cdk/core/.warnings.jsii.js")._aws_cdk_core_CfnTag(p.tags);
    visitedObjects.delete(p);
}
function _aws_cdk_aws_ivs_StreamKeyProps(p) {
    if (p == null)
        return;
    visitedObjects.add(p);
    if (!visitedObjects.has(p.channel))
        _aws_cdk_aws_ivs_IChannel(p.channel);
    visitedObjects.delete(p);
}
function _aws_cdk_aws_ivs_IChannel(p) {
}
function _aws_cdk_aws_ivs_CfnChannelProps(p) {
    if (p == null)
        return;
    visitedObjects.add(p);
    if (!visitedObjects.has(p.tags))
        require("@aws-cdk/core/.warnings.jsii.js")._aws_cdk_core_CfnTag(p.tags);
    visitedObjects.delete(p);
}
function _aws_cdk_aws_ivs_CfnRecordingConfigurationProps(p) {
    if (p == null)
        return;
    visitedObjects.add(p);
    if (!visitedObjects.has(p.tags))
        require("@aws-cdk/core/.warnings.jsii.js")._aws_cdk_core_CfnTag(p.tags);
    visitedObjects.delete(p);
}
function _aws_cdk_aws_ivs_PlaybackKeyPair(p) {
}
function _aws_cdk_aws_ivs_StreamKey(p) {
}
function _aws_cdk_aws_ivs_ChannelProps(p) {
    if (p == null)
        return;
    visitedObjects.add(p);
    if (!visitedObjects.has(p.latencyMode))
        _aws_cdk_aws_ivs_LatencyMode(p.latencyMode);
    if (!visitedObjects.has(p.type))
        _aws_cdk_aws_ivs_ChannelType(p.type);
    visitedObjects.delete(p);
}
function _aws_cdk_aws_ivs_CfnPlaybackKeyPair(p) {
}
function _aws_cdk_aws_ivs_CfnStreamKey(p) {
}
function _aws_cdk_aws_ivs_Channel(p) {
}
function _aws_cdk_aws_ivs_CfnChannel(p) {
}
function _aws_cdk_aws_ivs_CfnRecordingConfiguration(p) {
}
function _aws_cdk_aws_ivs_CfnRecordingConfiguration_S3DestinationConfigurationProperty(p) {
}
function _aws_cdk_aws_ivs_CfnRecordingConfiguration_DestinationConfigurationProperty(p) {
}
function print(name, deprecationMessage) {
    const deprecated = process.env.JSII_DEPRECATED;
    const deprecationMode = ["warn", "fail", "quiet"].includes(deprecated) ? deprecated : "warn";
    const message = `${name} is deprecated.\n  ${deprecationMessage}\n  This API will be removed in the next major release.`;
    switch (deprecationMode) {
        case "fail":
            throw new DeprecationError(message);
        case "warn":
            console.warn("[WARNING]", message);
            break;
    }
}
const visitedObjects = new Set();
class DeprecationError extends Error {
}
module.exports = { print, _aws_cdk_aws_ivs_LatencyMode, _aws_cdk_aws_ivs_ChannelType, _aws_cdk_aws_ivs_PlaybackKeyPairProps, _aws_cdk_aws_ivs_IPlaybackKeyPair, _aws_cdk_aws_ivs_IStreamKey, _aws_cdk_aws_ivs_CfnStreamKeyProps, _aws_cdk_aws_ivs_CfnPlaybackKeyPairProps, _aws_cdk_aws_ivs_StreamKeyProps, _aws_cdk_aws_ivs_IChannel, _aws_cdk_aws_ivs_CfnChannelProps, _aws_cdk_aws_ivs_CfnRecordingConfigurationProps, _aws_cdk_aws_ivs_PlaybackKeyPair, _aws_cdk_aws_ivs_StreamKey, _aws_cdk_aws_ivs_ChannelProps, _aws_cdk_aws_ivs_CfnPlaybackKeyPair, _aws_cdk_aws_ivs_CfnStreamKey, _aws_cdk_aws_ivs_Channel, _aws_cdk_aws_ivs_CfnChannel, _aws_cdk_aws_ivs_CfnRecordingConfiguration, _aws_cdk_aws_ivs_CfnRecordingConfiguration_S3DestinationConfigurationProperty, _aws_cdk_aws_ivs_CfnRecordingConfiguration_DestinationConfigurationProperty };
module.exports.DeprecationError = DeprecationError;

==> aws-cdk.aws-ivs-1.135.0.tar.gz: package/.warnings.jsii.js <==
function _aws_cdk_aws_ivs_LatencyMode(p) {
}
function _aws_cdk_aws_ivs_ChannelType(p) {
}
function _aws_cdk_aws_ivs_PlaybackKeyPairProps(p) {
}
function _aws_cdk_aws_ivs_IPlaybackKeyPair(p) {
}
function _aws_cdk_aws_ivs_IStreamKey(p) {
}
function _aws_cdk_aws_ivs_StreamKeyProps(p) {
    if (p == null)
        return;
    visitedObjects.add(p);
    if (!visitedObjects.has(p.channel))
        _aws_cdk_aws_ivs_IChannel(p.channel);
    visitedObjects.delete(p);
}
function _aws_cdk_aws_ivs_CfnStreamKeyProps(p) {
    if (p == null)
        return;
    visitedObjects.add(p);
    if (!visitedObjects.has(p.tags))
        require("@aws-cdk/core/.warnings.jsii.js")._aws_cdk_core_CfnTag(p.tags);
    visitedObjects.delete(p);
}
function _aws_cdk_aws_ivs_CfnPlaybackKeyPairProps(p) {
    if (p == null)
        return;
    visitedObjects.add(p);
    if (!visitedObjects.has(p.tags))
        require("@aws-cdk/core/.warnings.jsii.js")._aws_cdk_core_CfnTag(p.tags);
    visitedObjects.delete(p);
}
function _aws_cdk_aws_ivs_IChannel(p) {
}
function _aws_cdk_aws_ivs_CfnChannelProps(p) {
    if (p == null)
        return;
    visitedObjects.add(p);
    if (!visitedObjects.has(p.tags))
        require("@aws-cdk/core/.warnings.jsii.js")._aws_cdk_core_CfnTag(p.tags);
    visitedObjects.delete(p);
}
function _aws_cdk_aws_ivs_CfnRecordingConfigurationProps(p) {
    if (p == null)
        return;
    visitedObjects.add(p);
    if (!visitedObjects.has(p.tags))
        require("@aws-cdk/core/.warnings.jsii.js")._aws_cdk_core_CfnTag(p.tags);
    visitedObjects.delete(p);
}
function _aws_cdk_aws_ivs_PlaybackKeyPair(p) {
}
function _aws_cdk_aws_ivs_StreamKey(p) {
}
function _aws_cdk_aws_ivs_ChannelProps(p) {
    if (p == null)
        return;
    visitedObjects.add(p);
    if (!visitedObjects.has(p.latencyMode))
        _aws_cdk_aws_ivs_LatencyMode(p.latencyMode);
    if (!visitedObjects.has(p.type))
        _aws_cdk_aws_ivs_ChannelType(p.type);
    visitedObjects.delete(p);
}
function _aws_cdk_aws_ivs_CfnStreamKey(p) {
}
function _aws_cdk_aws_ivs_CfnPlaybackKeyPair(p) {
}
function _aws_cdk_aws_ivs_Channel(p) {
}
function _aws_cdk_aws_ivs_CfnChannel(p) {
}
function _aws_cdk_aws_ivs_CfnRecordingConfiguration(p) {
}
function _aws_cdk_aws_ivs_CfnRecordingConfiguration_S3DestinationConfigurationProperty(p) {
}
function _aws_cdk_aws_ivs_CfnRecordingConfiguration_DestinationConfigurationProperty(p) {
}
function print(name, deprecationMessage) {
    const deprecated = process.env.JSII_DEPRECATED;
    const deprecationMode = ["warn", "fail", "quiet"].includes(deprecated) ? deprecated : "warn";
    const message = `${name} is deprecated.\n  ${deprecationMessage}\n  This API will be removed in the next major release.`;
    switch (deprecationMode) {
        case "fail":
            throw new DeprecationError(message);
        case "warn":
            console.warn("[WARNING]", message);
            break;
    }
}
const visitedObjects = new Set();
class DeprecationError extends Error {
}
module.exports = { print, _aws_cdk_aws_ivs_LatencyMode, _aws_cdk_aws_ivs_ChannelType, _aws_cdk_aws_ivs_PlaybackKeyPairProps, _aws_cdk_aws_ivs_IPlaybackKeyPair, _aws_cdk_aws_ivs_IStreamKey, _aws_cdk_aws_ivs_StreamKeyProps, _aws_cdk_aws_ivs_CfnStreamKeyProps, _aws_cdk_aws_ivs_CfnPlaybackKeyPairProps, _aws_cdk_aws_ivs_IChannel, _aws_cdk_aws_ivs_CfnChannelProps, _aws_cdk_aws_ivs_CfnRecordingConfigurationProps, _aws_cdk_aws_ivs_PlaybackKeyPair, _aws_cdk_aws_ivs_StreamKey, _aws_cdk_aws_ivs_ChannelProps, _aws_cdk_aws_ivs_CfnStreamKey, _aws_cdk_aws_ivs_CfnPlaybackKeyPair, _aws_cdk_aws_ivs_Channel, _aws_cdk_aws_ivs_CfnChannel, _aws_cdk_aws_ivs_CfnRecordingConfiguration, _aws_cdk_aws_ivs_CfnRecordingConfiguration_S3DestinationConfigurationProperty, _aws_cdk_aws_ivs_CfnRecordingConfiguration_DestinationConfigurationProperty };
module.exports.DeprecationError = DeprecationError;
